.. -*- mode: rst ; ispell-local-dictionary: "american" -*-

.. include:: _manpage-header.rst


==========================
git flow
==========================


Synopsis
-----------

.. parsed-literal::

  ``git flow`` [-h]
  ``git flow`` subcommand [-h] [options]... [arguments]...


Description
-----------

Git extensions to provide high-level repository operations for Vincent
Driessen's branching model.


Options
-------------

  -h, --help       Show help message and exit


Subcommands
-------------

    :version:      Show the version of gitflow
    :status:       Show some status

    :init:         Initialize a repository for gitflow
    :feature:      Manage your feature branches
    :release:      Manage your release branches
    :hotfix:       Manage your hotfix branches
    :support:      Manage your support branches


.. include:: _manpage-footer.rst
